/**
 * 字符串工具类
 */
define(function(require, exports, module) {
    require("validatorUtils"); // 底层框架校验类
	
	/**
	 * 描述：金额格式化显示，如：6123432.24 -> 6,123,432.24
	 * 
	 * @author 汪卫中
	 * @param money: 金额
	 * @param decimal: 保留的小数位
	 */
	function moneyFormat(money, num){
        // 去掉字符串中除数字、点号、负号外的其他字符
        money = cusParseFloat((money + "").replace(/[^\d\.-]/g, ""));
        if (num != 0) {
            num = num ? num : 2;
        }
        money = money.toFixed(num);
        var re = /^(-?\d+)(\d{3})(\.?\d*)/;

        while(re.test(money)){
            money = money.replace(re, "$1,$2$3");
        }

        return money;
	}
	
	/**
	 * 描述：还原金额格式，如：6,123,432.24 -> 6123432.24
	 * 
	 * @author 汪卫中
	 * @param money: 待还原的金额字符串
	 */
	function restoreMoney(money){
		if (money) {
			return parseFloat(money.replace(/[^\d\.-]/g, ""));
		}
		return money;
	}
	
	/**
	 * 描述：保留指定位小数
	 * 
	 * @author 汪卫中
	 * @param numStr: 数字字符串
	 * @param digit: 需要保留的位数
	 */
	function numberDecimal(numStr, digit){
		if ($.validatorUtils.isNumeric(numStr)) {
			digit = digit ? digit : 0;
			return parseFloat(numStr).toFixed(digit);
		}
		
		return numStr;
	}
	
	/**
	 * 描述：手机号码隐藏中间4位 如：13212341234 -> 132****1234
	 * 
	 * @author 汪卫中
	 * @param mobile: 手机号码
	 * @returns 如果入参字符串长度小于11位时 返回原字符串。
	 */
	function hideMobilePos(mobile){
		// 校验是否为手机号码
		if (mobile) {
			mobile = mobile.replace(/(\d{3})\d{4}(\d{4})/, '$1****$2');
		}
		return mobile;
	}
	
	/**
	 * 描述：身份证号码隐藏后面8位 如：432524199003378776 -> 4325241990********
	 * 
	 * @author 汪卫中
	 * @param mobile: 身份证号码
	 * @returns 
	 */
	function hideIDCardPos(cardNum){
		if (cardNum) {
			cardNum = cardNum.replace(/(\d{5})\d+(\d{3})/, '$1**********$2');
		}
		
		return cardNum;
	}
	
	/**
	 * 描述：邮箱显示前2位+固定5个星号+@域名：kk*****@163.com。
	 * 
	 * @author 汪卫中
	 * @param mobile: 邮箱
	 * @returns 
	 */
	function hideEmailPos(email){
		if (email) {
			email = email.replace(/(.{2}).*(@{1}.*)/, "$1*****$2");
		}
		
		return email;
	}
	
	/**
	 * 描述：资金账号隐藏第4-7位 如：1040027011 -> 104****7011
	 * 
	 * @author 汪卫中
	 * @param fundAcct: 资金账号
	 * @returns 
	 */
	function hideFundAcctPos(fundAcct){
		if (fundAcct) {
			fundAcct = fundAcct.replace(/(\d{2})\d{4}(\d+)/, '$1 **** $2');
		}
		return fundAcct;
	}
	
	/**
	 * 描述：银行卡号显示前4位+固定8个星号+后4位：6226 ******** 2313
	 * 
	 * @author 汪卫中
	 * @param bankCard: 银行卡号
	 * @returns 
	 */
	function hideBankCardPos(bankCard, type){
		if (bankCard) {
			if (type == 1) {
				bankCard = bankCard.replace(/\d+(\d{4})/, '**** **** **** $1');
			} else {
				bankCard = bankCard.replace(/(\d{4})\d+(\d{4})/, '$1 **** $2');
			}
		}
		
		return bankCard;
	}
	
	/**
	 * 描述：显示银行卡尾号
	 * 
	 * @author 汪卫中
	 * @param bankCard: 银行卡号
	 * @returns 
	 */
	function showCardTailNum(bankCard){
		if (bankCard && bankCard.length > 4) {
			bankCard = bankCard.replace(/\d+(\d{4})/, '**** **** **** $1');
		}
		
		return bankCard;
	}
	
	/**
	 * 描述：截取银行卡尾号
	 * 
	 * @author 汪卫中
	 * @param bankCard: 银行卡号
	 * @returns 
	 */
	function getBankCardTailNum(bankCard){
		if (bankCard && bankCard.length > 4) {
			bankCard = bankCard.substring(bankCard.length - 4, bankCard.length);
		}
		
		return bankCard;
	}
	
	/**
	 * 描述：只显示姓隐藏2位：**张
	 * 
	 * @author 汪卫中
	 * @param userName: 用户姓名
	 * @returns 
	 */
	function hideUserNamePos(userName){
		userName = userName ? $.trim(userName) : ""; 
		
		if (userName && userName.length > 1) {
			var nameTemp = userName.substring(userName.length - 1, userName.length);
			for (var i = 0; i < userName.length - 1; i++) {
				nameTemp = "*" + nameTemp;
			}
			return nameTemp;
		}
		
		return userName;
	}
	
	/**
	 * 描述：重写 javascript parseInt 方法
	 * 
	 * @author 汪卫中
	 * @param str: 待转换的字符串，
	 * @param dftVal: 如果str为空或者parseInt解析结果为NaN时 返回的默认值 ，不传默认返回0
	 * @returns 
	 */
	function cusParseInt(str, dftVal){
		dftVal = dftVal || 0;
		var result = dftVal;
		if (str) {
			result = parseInt(str, 10) || dftVal; // 使用十进制进行转换
		}
		return result;
	}
	
	/**
	 * 描述：重写 javascript parseInt 方法
	 * 
	 * @author 汪卫中
	 * @param str: 待转换的字符串，
	 * @param dftVal: 如果str为空或者parseFloat解析结果为NaN时 返回的默认值 ，不传默认返回0
	 * @returns 
	 */
	function cusParseFloat(str, dftVal){
		dftVal = dftVal || 0;
		var result = dftVal;
		if (str) {
			result = parseFloat(str, 10) || dftVal; // 使用十进制进行转换
		}
		return result;
	}
	
	/**
	 * 描述： 数字大于一万时，以万为单位显示 如： 12345623 -> 1,234.56万
	 * @author 汪卫中
	 * @param num: 数字字符串
	 * @param dft: 字符串为空时默认显示值
	 */
	function dealBigNumber(num, dft){
		if($.validatorUtils.isEmpty(num)){
			num = dft || "--";
    	}else {
    		num = cusParseFloat(num);
        	if(num >= 1000 && num < 10000 ){
        		num = cusParseFloat(num).toLocaleString();
        	}else if( num >= 10000){
        		num = (num / 10000);
        		num = cusParseFloat(num).toLocaleString();
        		num = num + "万";
        	} else {
        		num = num.toLocaleString();
        	}
    	}
    	return num;
	}
	
	/**
	 * 描述：去掉字符串所有空格
	 * @author 汪卫中
	 * @param str: 字符串
	 */
	function trimAll(str){
		if (str) {
			return str.replaceAll(" ", "");
		}
		return str;
	}
	
	var stringUtils = {
		"moneyFormat" : moneyFormat, // 金额格式化显示，如：6123432.24 -> 6,123,432.24
		"restoreMoney" : restoreMoney, // 还原金额格式，如：6,123,432.24 -> 6123432.24
		"numberDecimal" : numberDecimal, // 保留指定位小数
		"hideMobilePos" : hideMobilePos, // 手机号码隐藏中间4位 如：13212341234 -> 132****1234
		"hideIDCardPos" : hideIDCardPos, // 身份证号码隐藏后面8位 如：432524199003378776 -> 4325241990********
		"hideEmailPos" : hideEmailPos, // 邮箱显示前2位+固定5个星号+@域名：kk*****@163.com。
		"hideFundAcctPos" : hideFundAcctPos, // 资金账号隐藏第4-7位 如：1040027011 -> 104****7011
		"hideBankCardPos" : hideBankCardPos, // 银行卡号显示前4位+固定8个星号+后4位：6226 ******** 2313
		"showCardTailNum" : showCardTailNum, // 显示银行卡尾号
		"getBankCardTailNum" : getBankCardTailNum, // 获取银行卡号后面4位
		"hideUserNamePos" : hideUserNamePos, // 姓名只显示姓隐藏2位：张**
		"parseInt" : cusParseInt, // 重写parseInt 方法
		"parseFloat" : cusParseFloat, // 重写parseFloat 方法
		"trimAll" : trimAll, // 去掉字符串所有空格
		"dealBigNumber" : dealBigNumber // 数字大于一万时，以万为单位显示 如： 12345623 -> 1,234.562万
	};

	//暴露对外的接口
	module.exports = stringUtils;
});